@@ -13,10 +13,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT ShiftReg : public LogicComponent
 {
     public:
-        ShiftReg( QObject* parent, QString type, QString id );
+        ShiftReg( QString type, QString id );
         ~ShiftReg();
 
-        static Component* construct( QObject* parent, QString type, QString id );
+        static Component* construct( QString type, QString id );
         static LibraryItem *libraryItem();
 
         virtual void stamp() override;
