@@ -13,10 +13,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT Voltimeter : public Meter
 {
     public:
-        Voltimeter( QObject* parent, QString type, QString id );
+        Voltimeter( QString type, QString id );
         ~Voltimeter();
 
-        static Component* construct( QObject* parent, QString type, QString id );
+        static Component* construct( QString type, QString id );
         static LibraryItem *libraryItem();
 
         virtual void updateStep() override;
