@@ -15,10 +15,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT Dial : public Dialed, public Linkable
 {
     public:
-        Dial( QObject* parent, QString type, QString id );
+        Dial( QString type, QString id );
         ~Dial();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         virtual void updateStep() override;
