@@ -13,10 +13,10 @@ class LibraryItem;
 class MAINMODULE_EXPORT Push : public PushBase
 {
     public:
-        Push( QObject* parent, QString type, QString id );
+        Push( QString type, QString id );
         ~Push();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
