@@ -18,21 +18,23 @@
 
 #include "intprop.h"
 
-Component* SwitchDip::construct( QObject* parent, QString type, QString id )
-{ return new SwitchDip( parent, type, id ); }
+#define tr(str) simulideTr("SwitchDip",str)
+
+Component* SwitchDip::construct( QString type, QString id )
+{ return new SwitchDip( type, id ); }
 
 LibraryItem* SwitchDip::libraryItem()
 {
     return new LibraryItem(
-        tr( "Switch Dip" ),
+        tr("Switch Dip"),
         "Switches",
         "switchdip.png",
         "SwitchDip",
         SwitchDip::construct);
 }
 
-SwitchDip::SwitchDip( QObject* parent, QString type, QString id )
-         : Component( parent, type, id )
+SwitchDip::SwitchDip( QString type, QString id )
+         : Component( type, id )
          , eElement( id )
 {
     m_graphical = true;
@@ -152,17 +154,14 @@ void SwitchDip::createSwitches( int c )
         
         QGraphicsProxyWidget* proxy = Circuit::self()->addWidget( button );
         proxy->setParentItem( this );
-        proxy->setPos( QPoint( 3, -27+i*8 ) );
+        proxy->setPos( QPoint( 3,-27+i*8 ) );
         m_proxys.append( proxy );
-        connect( button, &QPushButton::released,
-                   this, &SwitchDip::onbuttonclicked, Qt::UniqueConnection);
-        
-        QPoint pinpos = QPoint(-8,-32+8+i*8 );
-        Pin* pin = new Pin( 180, pinpos, butId+"-pinP", 0, this);
+        QObject::connect( button, &QPushButton::released, [=](){ onbuttonclicked(); });
+
+        Pin* pin = new Pin( 180, QPoint(-8,-32+8+i*8 ), butId+"-pinP", 0, this, 5 );
         m_pin[index] = pin;
-        
-        pinpos = QPoint( 16,-32+8+i*8 );
-        pin = new Pin( 0, pinpos, butId+"-pinN", 0, this);
+
+        pin = new Pin( 0, QPoint( 16,-32+8+i*8 ), butId+"-pinN", 0, this, 5 );
         m_pin[index+1] = pin;
         
         m_state |= 1<<i;                          // default state = on;
@@ -182,7 +181,7 @@ void SwitchDip::deleteSwitches( int d )
     for( int i=start; i<m_size; i++ )
     {
         QPushButton* button = m_buttons.takeLast();
-        disconnect( button, &QPushButton::released, this, &SwitchDip::onbuttonclicked );
+        /// FIXME: disconnect( button, &QPushButton::released, this, &SwitchDip::onbuttonclicked );
         delete button;
         
         m_proxys.removeLast();
