@@ -132,7 +132,8 @@ int McuCreator::processFile( QString fileName, bool main )
     if( root.hasAttribute("core") ) m_core = root.attribute("core");
 
     if( root.hasAttribute("progword") )   mcu->m_wordSize = root.attribute("progword").toUInt(0,0);
-    if( root.hasAttribute("inst_cycle") ) mcu->m_cPerInst = root.attribute("inst_cycle").toDouble();
+    if( root.hasAttribute("inst_cycle") ) mcu->setInstCycle( root.attribute("inst_cycle").toDouble() );
+    if( root.hasAttribute("cpu_cycle") )  mcu->m_cPerTick = root.attribute("cpu_cycle").toDouble();
     if( root.hasAttribute("data") )       createDataMem( root.attribute("data").toUInt(0,0) );
     if( root.hasAttribute("prog") )       createProgMem( root.attribute("prog").toUInt(0,0) );
     if( root.hasAttribute("eeprom") )     createRomMem( root.attribute("eeprom").toUInt(0,0) );
@@ -1171,7 +1172,7 @@ void McuCreator::createDisplay( QDomElement* e )
     else display = new Display( width, height, name, CircuitWidget::self() );
 
     if( e->hasAttribute("embeed") )
-        m_mcuComp->setBackImage( display->getImage() );
+        m_mcuComp->setBackData( display->getBackData() );
 
     if( e->hasAttribute("monitorscale") )
     {
@@ -1179,7 +1180,7 @@ void McuCreator::createDisplay( QDomElement* e )
         display->setMonitorScale( scale );
         m_displays.append( display );
     }
-    else delete display; /// Fix ???
+    else delete display; /// FIXME ???
 }
 
 void McuCreator::createStack( QDomElement* s )
